//import modules from d3 and json library
import {
  select,
  json,
  geoPath,
  geoNaturalEarth1,
} from 'd3';
import { feature } from 'topojson';

//select svg element in the DOM
const svg = select('svg');

//define geographic projection
const projection1 = geoNaturalEarth1();
const pathGenerator = geoPath().projection(
  projection1
);

//add a new path to svg element to represent sphere for geographic pojection
svg
  .append('path')
  .attr('class', 'sphere')
  .attr('d', pathGenerator({ type: 'Sphere' }));

json(
  'https://gist.githubusercontent.com/rakeshkommineni/efeecb24f879da0f635a2211f2908e0b/raw/f56186066d4be22ff5da37f9b67fdba67980f9fe/worldmap.json'
) //including json data from gist
  .then((data) => {
    //selecting countries from json data using feature method
    const countries = feature(
      data,
      data.objects.countries
    );
    //setting data join for path
    svg
      .selectAll('path')
      .data(countries.features)
      //appending new path to each element in data
      .enter()
      .append('path')
      //adding class name as country to style it
      .attr('class', 'country')
      //setting d attribute of path using pathGenerator based on countries
      .attr('d', pathGenerator);
  });
